---------------------------------------
Build the DnsCherry docs/website:
---------------------------------------

The dnscherry documentation/website is built using `Sphinx`_.

.. _Sphinx: http://sphinx.pocoo.org/

To build the docs you need to perform the following tasks:

* Install Sphinx (``$ sudo apt-get install python-sphinx``)
* From this ``docs`` directory, run: ``$ make html``
* This will produce HTML documentation in the ``_build/html/`` directory
* Open ``_build/html/index.html`` with your browser
